@@ -4,39 +4,39 @@ import pynotificator
 
 
 def beep_notify():
-    parser = argparse.ArgumentParser(description='ビープ音を鳴らす')
+    parser = argparse.ArgumentParser(description='Beep Notification')
     parser.add_argument('--times', '-t', type=int, default=1,
-                        help='ビープ音を鳴らす回数')
+                        help='The number of times of beep sound')
     args = parser.parse_args()
 
     bn = pynotificator.BeepNotification(args.times)
     bn.notify()
 
 
-def center_notify():
-    parser = argparse.ArgumentParser(description='通知を飛ばす')
+def desktop_notify():
+    parser = argparse.ArgumentParser(description='Desktop Notification')
     parser.add_argument('--message', '-m', default='PyNotificator',
-                        help='通知の内容')
+                        help='Content of notice')
     parser.add_argument('--title', '-t', default='',
-                        help='通知のタイトル')
+                        help='Title of notice')
     parser.add_argument('--subtitle', '-s', default='',
-                        help='通知のサブタイトル')
+                        help='Subtitle of notice')
     parser.add_argument('--icon', '-i', default='',
-                        help='アイコン')
+                        help='Icon of notice')
     parser.add_argument('--nosound', action='store_true',
-                        help='通知音を無効化')
+                        help='Disable notification sound')
     args = parser.parse_args()
 
-    cn = pynotificator.CenterNotification(
+    dn = pynotificator.DesktopNotification(
         args.message, args.title, args.subtitle, args.icon, not args.nosound)
-    cn.notify()
+    dn.notify()
 
 
 def slack_notify():
-    parser = argparse.ArgumentParser(description='Slack に通知をする')
+    parser = argparse.ArgumentParser(description='Slack Notification')
     parser.add_argument('--message', '-m', default='PyNotificator',
-                        help='通知の内容')
-    parser.add_argument('url', help='Incoming Webhook の URL')
+                        help='Content of notice')
+    parser.add_argument('url', help='Incoming Webhook URL')
     args = parser.parse_args()
 
     sn = pynotificator.SlackNotification(args.message, args.url)
@@ -44,10 +44,10 @@ def slack_notify():
 
 
 def discord_notify():
-    parser = argparse.ArgumentParser(description='Discord に通知をする')
+    parser = argparse.ArgumentParser(description='Discord Notification')
     parser.add_argument('--message', '-m', default='PyNotificator',
-                        help='通知の内容')
-    parser.add_argument('url', help='Discord の Webhook の URL')
+                        help='Content of notice')
+    parser.add_argument('url', help='Discord Webhook URL')
     args = parser.parse_args()
 
     dn = pynotificator.DiscordNotification(args.message, args.url)
@@ -55,10 +55,10 @@ def discord_notify():
 
 
 def line_notify():
-    parser = argparse.ArgumentParser(description='Line に通知をする')
+    parser = argparse.ArgumentParser(description='Line Notification')
     parser.add_argument('--message', '-m', default='PyNotificator',
-                        help='通知の内容')
-    parser.add_argument('token', help='LINE Notify のトークン')
+                        help='Content of notice')
+    parser.add_argument('token', help='LINE Notify token')
     args = parser.parse_args()
 
     ln = pynotificator.LineNotification(args.message, args.token)
